@@ -35,20 +35,13 @@ from .renderer.excel import ExcelRenderer
 storage_name = os.getenv('STORAGE_NAME')
 
 global ACCESS_KEY_ID, SECRET_ACCESS_KEY, REGION_NAME, BUCKET_NAME
-# ACCESS_KEY_ID = os.getenv('ACCESS_KEY_ID', '')
-# SECRET_ACCESS_KEY = os.getenv('SECRET_ACCESS_KEY', '')
-# REGION_NAME = os.getenv('REGION_NAME', '')
-# BUCKET_NAME = os.getenv('BUCKET_NAME', '')
-
 
 if storage_name == 's3':
-    print("=================== Storage Name=============", storage_name)
     ACCESS_KEY_ID = os.getenv('ACCESS_KEY_ID')
     SECRET_ACCESS_KEY = os.getenv('SECRET_ACCESS_KEY')
     REGION_NAME = os.getenv('REGION_NAME')
     BUCKET_NAME = os.getenv('BUCKET_NAME')
 elif storage_name == 'ceph':
-    print("=================== Storage Name=============", storage_name)
     ACCESS_KEY_ID = os.getenv('ACCESS_KEY_ID')
     SECRET_ACCESS_KEY = os.getenv('SECRET_ACCESS_KEY')
     BUCKET_NAME = os.getenv('BUCKET_NAME')
@@ -192,16 +185,13 @@ def get_result_by_run(run_id, field=None, default_value=None):
                 result = result.get(field, default_value)
             return result
         elif storage_name == 'ceph':
-            print("=========     Get result by Run ceph    =========")
             s3 = get_s3_ceph()
             data = BytesIO()
             res_object = s3.Bucket(BUCKET_NAME).download_fileobj(Fileobj=data,Key=run_id)   
             res_object = data.getvalue()
             result = json.loads(res_object)
-            print("get result by run result = ", result)
             if field:
                 result = result.get(field, default_value)
-                print("sdk get result by run result ============= ", result)
             return result
         else:
             logger.info("No storages are found")
@@ -288,10 +278,8 @@ def upload_to_s3(content, location):
             pass
     elif storage_name == 'ceph':
         try:
-            print("=============upload to s3 method====================", ENDPOINT_URL, ACCESS_KEY_ID, SECRET_ACCESS_KEY)
             s3 = boto3.resource('s3',
                                 endpoint_url=ENDPOINT_URL,
-                                # endpoint_url=ENDPOINT_URL,
                                 aws_access_key_id=ACCESS_KEY_ID,
                                 aws_secret_access_key=SECRET_ACCESS_KEY)
             s3.Bucket(BUCKET_NAME).put_object(Bucket=BUCKET_NAME,
@@ -303,23 +291,11 @@ def upload_to_s3(content, location):
             pass
     else:
         logger.info("No storages are found")
-    # try:
-    #     s3.Bucket(BUCKET_NAME).put_object(Body=content,
-    #                                          Key=location)
-    #     #return object_url
-    #     return location
-    # except Exception:
-    #     pass
-    
-
-
-
+        
 
 def generate_pdf(analysis_run):
     logger.info('Entered into pdf generation process')
     url = os.getenv("PDF_SERVICE")
-    print("++++++++++++ run_id +++++++++ = ", analysis_run)
-    print("+++++++++++++++generate pdf function+++++++++++++++++", BASE_API_URL, PLATFORM_ROUTE, APP_ID)
     # analysis_run = json.dumps(analysis_run)
     data = {
         'domain': BASE_API_URL,
@@ -342,9 +318,9 @@ def generate_pdf(analysis_run):
 
 
 
-def generate_excel(analysis_run, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
+def generate_excel(analysis_run, orgId, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
     try:
-        excel_renderer = ExcelRenderer(analysis_run, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time)
+        excel_renderer = ExcelRenderer(analysis_run, orgId, excel_data, report_gen_start_time, report_gen_completed_time)
         workbook = excel_renderer.render()
     except Exception as ex:
         raise ex
@@ -364,9 +340,9 @@ def diff_sec(st, et):
     return difference
 
 
-def update_status_url(analysisRunId, tenantId, integrationId, genStime, genEtime, status=None):
+def update_status_url(analysisRunId, tenantId, genStime, genEtime, status=None):
 
-    url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/runs/{analysisRunId}'
+    url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
     data={
             "status" : status,
             "runDurStartDate" : genStime,
@@ -382,15 +358,24 @@ def update_status_url(analysisRunId, tenantId, integrationId, genStime, genEtime
     logger.info('Status update response is %s', res)
 
 
-def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, failure_reason=None, status=None):
+def update_results_url(gen_start_time, analysisRunId, tenantId, json_result_url=None, gen_completed_time=None, excel_result_url=None, pdf_result_url=None, failure_reason=None, status=None):
 
-    url = BASE_API_URL + f'/analytics/api/v7/tenants/{tenantId}/runs/{analysisRunId}'
+    url = BASE_API_URL + f'/analytics/api/v3/tenants/{tenantId}/runs/{analysisRunId}'
     
     if pdf_result_url == None:
         data={
                 "status" : status,
                 "resultUrl" : json_result_url,
-                "filePath" : excel_result_url,
+                "xlsxFilePath" : excel_result_url,
+                "repGenStartTime" : gen_start_time,
+                "repGenEndTime" : gen_completed_time,
+                "failureReason" : failure_reason
+        }
+    elif excel_result_url == None:
+        data={
+                "status" : status,
+                "resultUrl" : json_result_url,
+                "pdfFilePath" : pdf_result_url,
                 "repGenStartTime" : gen_start_time,
                 "repGenEndTime" : gen_completed_time,
                 "failureReason" : failure_reason
@@ -399,7 +384,8 @@ def update_results_url(gen_start_time, analysisRunId, tenantId, integrationId, j
         data={
                 "status" : status,
                 "resultUrl" : json_result_url,
-                "filePath" : pdf_result_url,
+                "pdfFilePath" : pdf_result_url,
+                "xlsxFilePath" : excel_result_url,
                 "repGenStartTime" : gen_start_time,
                 "repGenEndTime" : gen_completed_time,
                 "failureReason" : failure_reason
@@ -434,11 +420,9 @@ def upload_excel_s3(local_file, bucket, s3_file):
 
 #Upload excel file to ceph
 def upload_excel_ceph(local_file, bucket, s3_file):
-    s3 = get_s3_ceph()
     try:
+        s3 = get_s3_ceph()
         s3.upload_file(Filename = local_file, Key = s3_file)
-        # url = f'https://{bucket}.s3.{REGION_NAME}.amazonaws.com/{s3_file}'
-        # logger.info('Upload successful, result url is %s', url)
         
         delete_excel_file(local_file)
         return s3_file
@@ -460,12 +444,12 @@ def delete_excel_file(source_path):
 
 
 #Generate excel file
-def generate_excel_file(run_id, orgId, integrationId, report_gen_start_time, report_gen_completed_time):
+def generate_excel_file(run_id, orgId, report_gen_start_time, report_gen_completed_time):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
     reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
-    generate_excel(run_id, orgId, integrationId, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
+    generate_excel(run_id, orgId, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
     excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
     if storage_name == 's3':
         excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
